@@ -75,6 +75,7 @@
 #' 
 #' @export plotScoresRGL
 #' @importFrom ChemoSpecUtils sumGroups
+#' @importFrom ChemoSpecUtils .getVarExplained
 #'
 plotScoresRGL <- function(spectra, pca, pcs = c(1:3), 
 	ellipse = TRUE, rob = FALSE, cl = 0.95, frac.pts.used = 0.8,
@@ -92,8 +93,7 @@ plotScoresRGL <- function(spectra, pca, pcs = c(1:3),
 	lets <- spectra$alt.sym
 	gr <- sumGroups(spectra)
 	
-	eigensum <- sum(pca$sdev*pca$sdev) # prepare axis labels
-	variance <- 100*(pca$sdev*pca$sdev/eigensum)
+	variance <- .getVarExplained(pca)
 	x.lab <- paste("PC", pcs[1], " (", format(variance[1], digits=2), "%", ")", sep = "")
 	y.lab <- paste("PC", pcs[2], " (", format(variance[2], digits=2), "%", ")", sep = "")
 	z.lab <- paste("PC", pcs[3], " (", format(variance[3], digits=2), "%", ")", sep = "")
