@@ -5,10 +5,7 @@
 surveySpectra2 <- function(spectra, method = c("sd", "sem", "sem95", "mad", "iqr"),
 	lab.pos = 0.9*max(spectra$freq), ...) {
 
-# Function to visually inspect a Spectra object holistically.
-# Part of the ChemoSpec package
-# Bryan Hanson, DePauw University, May 2015
-
+	.chkArgs(mode = 11L)
 	chkSpectra(spectra)
 	
 	x <- spectra$freq
